@@ -3,8 +3,13 @@ Puppet::Type.type(:neutron_plugin_midonet).provide(
   :parent => Puppet::Type.type(:openstack_config).provider(:ini_setting)
 ) do
 
-  def file_path
+  def self.file_path
     '/etc/neutron/plugins/midonet/midonet.ini'
   end
 
+  # added for backwards compatibility with older versions of inifile
+  def file_path
+    self.class.file_path
+  end
+
 end
