@@ -14,9 +14,9 @@ describe 'neutron::agents::lbaas' do
     { :package_ensure   => 'present',
       :enabled          => true,
       :interface_driver => 'neutron.agent.linux.interface.OVSInterfaceDriver',
-      :device_driver    => 'neutron_lbaas.services.loadbalancer.drivers.haproxy.namespace_driver.HaproxyNSDriver',
-      :use_namespaces   => nil,
-      :manage_haproxy_package  => true
+      :device_driver    => 'neutron_lbaas.drivers.haproxy.namespace_driver.HaproxyNSDriver',
+      :manage_haproxy_package  => true,
+      :purge_config            => false
     }
   end
 
@@ -37,6 +37,12 @@ describe 'neutron::agents::lbaas' do
     it_configures 'haproxy lbaas_driver'
     it_configures 'haproxy lbaas_driver without package'
 
+    it 'passes purge to resource' do
+      is_expected.to contain_resources('neutron_lbaas_agent_config').with({
+        :purge => false
+      })
+    end
+
     it 'configures lbaas_agent.ini' do
       is_expected.to contain_neutron_lbaas_agent_config('DEFAULT/debug').with_value('<SERVICE DEFAULT>');
       is_expected.to contain_neutron_lbaas_agent_config('DEFAULT/interface_driver').with_value(p[:interface_driver]);
@@ -45,23 +51,23 @@ describe 'neutron::agents::lbaas' do
     end
 
     it 'installs neutron lbaas agent package' do
-      is_expected.to contain_package('neutron-lbaas-agent').with(
+      is_expected.to contain_package('neutron-lbaasv2-agent').with(
         :name   => platform_params[:lbaas_agent_package],
         :ensure => p[:package_ensure],
         :tag    => ['openstack', 'neutron-package'],
       )
-      is_expected.to contain_package('neutron').with_before(/Package\[neutron-lbaas-agent\]/)
+      is_expected.to contain_package('neutron').with_before(/Package\[neutron-lbaasv2-agent\]/)
     end
 
     it 'configures neutron lbaas agent service' do
-      is_expected.to contain_service('neutron-lbaas-service').with(
+      is_expected.to contain_service('neutron-lbaasv2-service').with(
         :name    => platform_params[:lbaas_agent_service],
         :enable  => true,
         :ensure  => 'running',
-        :require => 'Class[Neutron]',
         :tag     => 'neutron-service',
       )
-      is_expected.to contain_service('neutron-lbaas-service').that_subscribes_to( [ 'Package[neutron]', 'Package[neutron-lbaas-agent]' ] )
+      is_expected.to contain_service('neutron-lbaasv2-service').that_subscribes_to('Anchor[neutron::service::begin]')
+      is_expected.to contain_service('neutron-lbaasv2-service').that_notifies('Anchor[neutron::service::end]')
     end
 
     context 'with manage_service as false' do
@@ -69,16 +75,9 @@ describe 'neutron::agents::lbaas' do
         params.merge!(:manage_service => false)
       end
       it 'should not start/stop service' do
-        is_expected.to contain_service('neutron-lbaas-service').without_ensure
-      end
-    end
-
-    context 'with use_namespaces as false' do
-      before :each do
-        params.merge!(:use_namespaces => false)
-      end
-      it 'should set use_namespaces option' do
-        is_expected.to contain_neutron_lbaas_agent_config('DEFAULT/use_namespaces').with_value(p[:use_namespaces])
+        is_expected.to contain_service('neutron-lbaasv2-service').with(
+          :ensure => 'stopped',
+        )
       end
     end
   end
@@ -86,7 +85,7 @@ describe 'neutron::agents::lbaas' do
   shared_examples_for 'haproxy lbaas_driver' do
     it 'installs haproxy packages' do
       if platform_params.has_key?(:lbaas_agent_package)
-        is_expected.to contain_package(platform_params[:haproxy_package]).with_before(['Package[neutron-lbaas-agent]'])
+        is_expected.to contain_package(platform_params[:haproxy_package]).with_before(['Package[neutron-lbaasv2-agent]'])
       end
       is_expected.to contain_package(platform_params[:haproxy_package]).with(
         :ensure => 'present'
@@ -122,9 +121,9 @@ describe 'neutron::agents::lbaas' do
 
     let :platform_params do
       { :haproxy_package     =>  'haproxy',
-        :lbaas_agent_package => 'neutron-lbaas-agent',
+        :lbaas_agent_package => 'neutron-lbaasv2-agent',
         :nobody_user_group   => 'nogroup',
-        :lbaas_agent_service => 'neutron-lbaas-agent' }
+        :lbaas_agent_service => 'neutron-lbaasv2-agent' }
     end
 
     it_configures 'neutron lbaas agent'
@@ -144,7 +143,7 @@ describe 'neutron::agents::lbaas' do
       { :haproxy_package     => 'haproxy',
         :lbaas_agent_package => 'openstack-neutron-lbaas',
         :nobody_user_group   => 'nobody',
-        :lbaas_agent_service => 'neutron-lbaas-agent' }
+        :lbaas_agent_service => 'neutron-lbaasv2-agent' }
     end
 
     it_configures 'neutron lbaas agent'
