@@ -35,6 +35,7 @@ describe 'neutron::agents::vpnaas' do
       :enabled                     => true,
       :vpn_device_driver           => 'neutron.services.vpn.device_drivers.ipsec.OpenSwanDriver',
       :interface_driver            => 'neutron.agent.linux.interface.OVSInterfaceDriver',
+      :purge_config                => false,
     }
   end
 
@@ -53,6 +54,12 @@ describe 'neutron::agents::vpnaas' do
 
     it_configures 'openswan vpnaas_driver'
 
+    it 'passes purge to resource' do
+      is_expected.to contain_resources('neutron_vpnaas_agent_config').with({
+        :purge => false
+      })
+    end
+
     it 'configures vpnaas_agent.ini' do
       is_expected.to contain_neutron_vpnaas_agent_config('vpnagent/vpn_device_driver').with_value(p[:vpn_device_driver]);
       is_expected.to contain_neutron_vpnaas_agent_config('ipsec/ipsec_status_check_interval').with_value('<SERVICE DEFAULT>');
@@ -79,7 +86,8 @@ describe 'neutron::agents::vpnaas' do
           :ensure => p[:package_ensure],
           :tag    => ['openstack', 'neutron-package'],
         )
-        is_expected.to contain_package('neutron').with_before(/Package\[neutron-vpnaas-agent\]/)
+        is_expected.to contain_package('neutron').that_requires('Anchor[neutron::install::begin]')
+        is_expected.to contain_package('neutron').that_notifies('Anchor[neutron::install::end]')
       end
     end
 
@@ -88,10 +96,10 @@ describe 'neutron::agents::vpnaas' do
         :name    => platform_params[:vpnaas_agent_service],
         :enable  => true,
         :ensure  => 'running',
-        :require => 'Class[Neutron]',
         :tag     => 'neutron-service',
       )
-      is_expected.to contain_service('neutron-vpnaas-service').that_subscribes_to('Package[neutron]')
+      is_expected.to contain_service('neutron-vpnaas-service').that_subscribes_to('Anchor[neutron::service::begin]')
+      is_expected.to contain_service('neutron-vpnaas-service').that_notifies('Anchor[neutron::service::end]')
     end
 
     context 'with manage_service as false' do
@@ -107,7 +115,7 @@ describe 'neutron::agents::vpnaas' do
   shared_examples_for 'openswan vpnaas_driver' do
     it 'installs openswan packages' do
       if platform_params.has_key?(:vpnaas_agent_package)
-        is_expected.to contain_package('openswan').with_before(['Package[neutron-vpnaas-agent]'])
+        is_expected.to contain_package('openswan')
       end
       is_expected.to contain_package('openswan').with(
         :ensure => 'present',
@@ -131,7 +139,8 @@ describe 'neutron::agents::vpnaas' do
 
     it_configures 'neutron vpnaas agent'
     it 'configures subscription to neutron-vpnaas-agent package' do
-      is_expected.to contain_service('neutron-vpnaas-service').that_subscribes_to('Package[neutron-vpnaas-agent]')
+      is_expected.to contain_service('neutron-vpnaas-service').that_subscribes_to('Anchor[neutron::service::begin]')
+      is_expected.to contain_service('neutron-vpnaas-service').that_notifies('Anchor[neutron::service::end]')
     end
 
     context 'when configuring the LibreSwan driver' do
