@@ -11,6 +11,7 @@ describe 'neutron::db' do
       it { is_expected.to contain_neutron_config('database/min_pool_size').with_value('<SERVICE DEFAULT>') }
       it { is_expected.to contain_neutron_config('database/max_retries').with_value('<SERVICE DEFAULT>') }
       it { is_expected.to contain_neutron_config('database/retry_interval').with_value('<SERVICE DEFAULT>') }
+      it { is_expected.to contain_neutron_config('database/db_max_retries').with_value('<SERVICE DEFAULT>') }
 
     end
 
@@ -20,7 +21,8 @@ describe 'neutron::db' do
           :database_idle_timeout   => '3601',
           :database_min_pool_size  => '2',
           :database_max_retries    => '11',
-          :database_retry_interval => '11', }
+          :database_retry_interval => '11',
+          :database_db_max_retries => '-1', }
       end
 
       it { is_expected.to contain_neutron_config('database/connection').with_value('mysql+pymysql://neutron:neutron@localhost/neutron').with_secret(true) }
@@ -28,6 +30,7 @@ describe 'neutron::db' do
       it { is_expected.to contain_neutron_config('database/min_pool_size').with_value('2') }
       it { is_expected.to contain_neutron_config('database/max_retries').with_value('11') }
       it { is_expected.to contain_neutron_config('database/retry_interval').with_value('11') }
+      it { is_expected.to contain_neutron_config('database/db_max_retries').with_value('-1') }
 
     end
 
@@ -84,7 +87,7 @@ describe 'neutron::db' do
         { :database_connection     => 'mysql+pymysql://neutron:neutron@localhost/neutron' }
       end
 
-      it { is_expected.to contain_package('neutron-backend-package').with({ :ensure => 'present', :name => 'python-pymysql' }) }
+      it { is_expected.to contain_package('db_backend_package').with({ :ensure => 'present', :name => 'python-pymysql' }) }
     end
 
   end
@@ -104,7 +107,7 @@ describe 'neutron::db' do
         { :database_connection     => 'mysql+pymysql://neutron:neutron@localhost/neutron' }
       end
 
-      it { is_expected.not_to contain_package('neutron-backend-package') }
+      it { is_expected.not_to contain_package('db_backend_package') }
     end
 
   end
