@@ -6,12 +6,9 @@ describe 'neutron' do
     { :package_ensure        => 'present',
       :core_plugin           => 'linuxbridge',
       :auth_strategy         => 'keystone',
-      :rabbit_hosts          => false,
-      :rabbit_host           => '127.0.0.1',
-      :rabbit_port           => 5672,
-      :rabbit_user           => 'guest',
       :rabbit_password       => 'guest',
       :log_dir               => '/var/log/neutron',
+      :purge_config          => false,
     }
   end
 
@@ -28,10 +25,6 @@ describe 'neutron' do
     end
 
     context 'and if rabbit_hosts parameter is provided' do
-      before do
-        params.delete(:rabbit_host)
-        params.delete(:rabbit_port)
-      end
 
       context 'with one server' do
         before { params.merge!( :rabbit_hosts => ['127.0.0.1:5672'] ) }
@@ -51,8 +44,15 @@ describe 'neutron' do
         it_configures 'rabbit_ha_queues set to false'
       end
 
+      context 'with non-default notification options' do
+        before { params.merge!( :notification_driver => 'messagingv2',
+                                :notification_topics => 'notifications',
+                                :notification_transport_url => 'rabbit://me:passwd@host:5672/virtual_host' ) }
+        it_configures 'notification_driver and notification_topics'
+      end
+
       it 'configures logging' do
-        is_expected.to contain_neutron_config('DEFAULT/log_file').with_ensure('absent')
+        is_expected.to contain_neutron_config('DEFAULT/log_file').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_neutron_config('DEFAULT/log_dir').with_value(params[:log_dir])
         is_expected.to contain_neutron_config('DEFAULT/use_stderr').with_value('<SERVICE DEFAULT>')
       end
@@ -69,24 +69,34 @@ describe 'neutron' do
       it_configures 'rabbit with durable queues'
     end
 
+    context 'with rabbitmq non default transient_queues_ttl' do
+      before { params.merge!( :rabbit_transient_queues_ttl => 20 ) }
+      it_configures 'rabbit with non default transient_queues_ttl'
+    end
+
+
     it_configures 'with SSL enabled with kombu'
     it_configures 'with SSL enabled without kombu'
     it_configures 'with SSL disabled'
-    it_configures 'with SSL wrongly configured'
     it_configures 'with SSL and kombu wrongly configured'
     it_configures 'with SSL socket options set'
     it_configures 'with SSL socket options set with wrong parameters'
     it_configures 'with SSL socket options left by default'
     it_configures 'with syslog disabled'
     it_configures 'with syslog enabled'
-    it_configures 'with syslog enabled and custom settings'
     it_configures 'with log_file specified'
-    it_configures 'with logging disabled'
     it_configures 'without service_plugins'
     it_configures 'with service_plugins'
     it_configures 'without memcache_servers'
     it_configures 'with memcache_servers'
+    it_configures 'with host defined'
     it_configures 'with dns_domain defined'
+    it_configures 'with transport_url defined'
+    it_configures 'with rootwrap daemon'
+
+    context 'with amqp rpc_backend value' do
+      it_configures 'amqp support'
+    end
   end
 
   shared_examples_for 'a neutron base installation' do
@@ -101,18 +111,32 @@ describe 'neutron' do
       )
     end
 
+    it 'passes purge to resource' do
+      is_expected.to contain_resources('neutron_config').with({
+        :purge => false
+      })
+    end
+
+    it 'configures messaging notifications' do
+      is_expected.to contain_neutron_config('oslo_messaging_notifications/driver').with_value('<SERVICE DEFAULT>')
+      is_expected.to contain_neutron_config('oslo_messaging_notifications/topics').with_value('<SERVICE DEFAULT>')
+      is_expected.to contain_neutron_config('oslo_messaging_notifications/transport_url').with_value('<SERVICE DEFAULT>')
+    end
+
     it 'configures credentials for rabbit' do
-      is_expected.to contain_neutron_config('oslo_messaging_rabbit/rabbit_userid').with_value( params[:rabbit_user] )
+      is_expected.to contain_neutron_config('oslo_messaging_rabbit/rabbit_userid').with_value( '<SERVICE DEFAULT>' )
       is_expected.to contain_neutron_config('oslo_messaging_rabbit/rabbit_password').with_value( params[:rabbit_password] )
       is_expected.to contain_neutron_config('oslo_messaging_rabbit/rabbit_password').with_secret( true )
       is_expected.to contain_neutron_config('oslo_messaging_rabbit/rabbit_virtual_host').with_value( '<SERVICE DEFAULT>' )
-      is_expected.to contain_neutron_config('oslo_messaging_rabbit/heartbeat_timeout_threshold').with_value('0')
-      is_expected.to contain_neutron_config('oslo_messaging_rabbit/heartbeat_rate').with_value('2')
+      is_expected.to contain_neutron_config('oslo_messaging_rabbit/heartbeat_timeout_threshold').with_value('<SERVICE DEFAULT>')
+      is_expected.to contain_neutron_config('oslo_messaging_rabbit/heartbeat_rate').with_value('<SERVICE DEFAULT>')
       is_expected.to contain_neutron_config('oslo_messaging_rabbit/kombu_reconnect_delay').with_value( '<SERVICE DEFAULT>' )
+      is_expected.to contain_neutron_config('oslo_messaging_rabbit/kombu_missing_consumer_retry_timeout').with_value( '<SERVICE DEFAULT>' )
+      is_expected.to contain_neutron_config('oslo_messaging_rabbit/kombu_failover_strategy').with_value( '<SERVICE DEFAULT>' )
+      is_expected.to contain_neutron_config('oslo_messaging_rabbit/kombu_compression').with_value( '<SERVICE DEFAULT>' )
     end
 
     it 'configures neutron.conf' do
-      is_expected.to contain_neutron_config('DEFAULT/verbose').with_value( '<SERVICE DEFAULT>' )
       is_expected.to contain_neutron_config('DEFAULT/bind_host').with_value('<SERVICE DEFAULT>')
       is_expected.to contain_neutron_config('DEFAULT/bind_port').with_value('<SERVICE DEFAULT>')
       is_expected.to contain_neutron_config('DEFAULT/auth_strategy').with_value('keystone')
@@ -120,38 +144,38 @@ describe 'neutron' do
       is_expected.to contain_neutron_config('DEFAULT/base_mac').with_value('<SERVICE DEFAULT>')
       is_expected.to contain_neutron_config('DEFAULT/mac_generation_retries').with_value('<SERVICE DEFAULT>')
       is_expected.to contain_neutron_config('DEFAULT/dhcp_lease_duration').with_value('<SERVICE DEFAULT>')
+      is_expected.to contain_neutron_config('DEFAULT/host').with_value('<SERVICE DEFAULT>')
       is_expected.to contain_neutron_config('DEFAULT/dns_domain').with_value('<SERVICE DEFAULT>')
       is_expected.to contain_neutron_config('DEFAULT/dhcp_agents_per_network').with_value('<SERVICE DEFAULT>')
-      is_expected.to contain_neutron_config('DEFAULT/network_device_mtu').with_value('<SERVICE DEFAULT>')
+      is_expected.to contain_neutron_config('DEFAULT/global_physnet_mtu').with_value('<SERVICE DEFAULT>')
       is_expected.to contain_neutron_config('DEFAULT/dhcp_agent_notification').with_value('<SERVICE DEFAULT>')
-      is_expected.to contain_neutron_config('DEFAULT/advertise_mtu').with_value('<SERVICE DEFAULT>')
       is_expected.to contain_neutron_config('DEFAULT/allow_bulk').with_value('<SERVICE DEFAULT>')
-      is_expected.to contain_neutron_config('DEFAULT/allow_pagination').with_value('<SERVICE DEFAULT>')
-      is_expected.to contain_neutron_config('DEFAULT/allow_sorting').with_value('<SERVICE DEFAULT>')
       is_expected.to contain_neutron_config('DEFAULT/allow_overlapping_ips').with_value('<SERVICE DEFAULT>')
       is_expected.to contain_neutron_config('DEFAULT/api_extensions_path').with_value('<SERVICE DEFAULT>')
       is_expected.to contain_neutron_config('DEFAULT/control_exchange').with_value('neutron')
       is_expected.to contain_neutron_config('DEFAULT/state_path').with_value('<SERVICE DEFAULT>')
       is_expected.to contain_neutron_config('oslo_concurrency/lock_path').with_value('$state_path/lock')
+      is_expected.to contain_neutron_config('DEFAULT/transport_url').with_value('<SERVICE DEFAULT>')
       is_expected.to contain_neutron_config('DEFAULT/rpc_response_timeout').with_value( '<SERVICE DEFAULT>' )
       is_expected.to contain_neutron_config('agent/root_helper').with_value('sudo neutron-rootwrap /etc/neutron/rootwrap.conf')
+      is_expected.to contain_neutron_config('agent/root_helper_daemon').with_value('<SERVICE DEFAULT>')
       is_expected.to contain_neutron_config('agent/report_interval').with_value('<SERVICE DEFAULT>')
     end
   end
 
   shared_examples_for 'rabbit HA with a single virtual host' do
     it 'in neutron.conf' do
-      is_expected.not_to contain_neutron_config('oslo_messaging_rabbit/rabbit_host')
-      is_expected.not_to contain_neutron_config('oslo_messaging_rabbit/rabbit_port')
+      is_expected.to contain_neutron_config('oslo_messaging_rabbit/rabbit_host').with_value('<SERVICE DEFAULT>')
+      is_expected.to contain_neutron_config('oslo_messaging_rabbit/rabbit_port').with_value('<SERVICE DEFAULT>')
       is_expected.to contain_neutron_config('oslo_messaging_rabbit/rabbit_hosts').with_value( params[:rabbit_hosts] )
-      is_expected.to contain_neutron_config('oslo_messaging_rabbit/rabbit_ha_queues').with_value(true)
+      is_expected.to contain_neutron_config('oslo_messaging_rabbit/rabbit_ha_queues').with_value('<SERVICE DEFAULT>')
     end
   end
 
   shared_examples_for 'rabbit HA with multiple hosts' do
     it 'in neutron.conf' do
-      is_expected.not_to contain_neutron_config('oslo_messaging_rabbit/rabbit_host')
-      is_expected.not_to contain_neutron_config('oslo_messaging_rabbit/rabbit_port')
+      is_expected.to contain_neutron_config('oslo_messaging_rabbit/rabbit_host').with_value('<SERVICE DEFAULT>')
+      is_expected.to contain_neutron_config('oslo_messaging_rabbit/rabbit_port').with_value('<SERVICE DEFAULT>')
       is_expected.to contain_neutron_config('oslo_messaging_rabbit/rabbit_hosts').with_value( params[:rabbit_hosts].join(',') )
       is_expected.to contain_neutron_config('oslo_messaging_rabbit/rabbit_ha_queues').with_value(true)
     end
@@ -170,12 +194,26 @@ describe 'neutron' do
     end
   end
 
+  shared_examples_for 'rabbit with non default transient_queues_ttl' do
+    it 'in neutron.conf' do
+      is_expected.to contain_neutron_config('oslo_messaging_rabbit/rabbit_transient_queues_ttl').with_value(20)
+    end
+  end
+
   shared_examples_for 'rabbit_ha_queues set to false' do
     it 'in neutron.conf' do
       is_expected.to contain_neutron_config('oslo_messaging_rabbit/rabbit_ha_queues').with_value(false)
     end
   end
 
+  shared_examples_for 'notification_driver and notification_topics' do
+    it 'in neutron.conf' do
+      is_expected.to contain_neutron_config('oslo_messaging_notifications/driver').with_value( params[:notification_driver] )
+      is_expected.to contain_neutron_config('oslo_messaging_notifications/topics').with_value( params[:notification_topics] )
+      is_expected.to contain_neutron_config('oslo_messaging_notifications/transport_url').with_value( params[:notification_transport_url] )
+    end
+  end
+
   shared_examples_for 'with SSL socket options set' do
     before do
       params.merge!(
@@ -247,6 +285,24 @@ describe 'neutron' do
     it { is_expected.to contain_neutron_config('DEFAULT/use_syslog').with_value(false) }
   end
 
+  shared_examples_for 'with non-default kombu options' do
+    before do
+      params.merge!(
+        :kombu_missing_consumer_retry_timeout => '5',
+        :kombu_failover_strategy              => 'shuffle',
+        :kombu_compression                    => 'gzip',
+        :kombu_reconnect_delay                => '30',
+      )
+    end
+
+    it do
+      is_expected.to contain_neutron_config('oslo_messaging_rabbit/kombu_reconnect_delay').with_value('30')
+      is_expected.to contain_neutron_config('oslo_messaging_rabbit/kombu_missing_consumer_retry_timeout').with_value('5')
+      is_expected.to contain_neutron_config('oslo_messaging_rabbit/kombu_failover_strategy').with_value('shuffle')
+      is_expected.to contain_neutron_config('oslo_messaging_rabbit/kombu_compression').with_value('gzip')
+    end
+  end
+
   shared_examples_for 'with SSL enabled with kombu' do
     before do
       params.merge!(
@@ -279,53 +335,21 @@ describe 'neutron' do
       is_expected.to contain_neutron_config('oslo_messaging_rabbit/kombu_ssl_ca_certs').with_value('<SERVICE DEFAULT>')
       is_expected.to contain_neutron_config('oslo_messaging_rabbit/kombu_ssl_certfile').with_value('<SERVICE DEFAULT>')
       is_expected.to contain_neutron_config('oslo_messaging_rabbit/kombu_ssl_keyfile').with_value('<SERVICE DEFAULT>')
-      is_expected.to contain_neutron_config('oslo_messaging_rabbit/kombu_ssl_version').with_value('TLSv1')
+      is_expected.to contain_neutron_config('oslo_messaging_rabbit/kombu_ssl_version').with_value('<SERVICE DEFAULT>')
     end
   end
 
   shared_examples_for 'with SSL disabled' do
-    before do
-      params.merge!(
-        :kombu_ssl_version  => 'TLSv1'
-      )
-    end
 
     it do
       is_expected.to contain_neutron_config('oslo_messaging_rabbit/rabbit_use_ssl').with_value('<SERVICE DEFAULT>')
       is_expected.to contain_neutron_config('oslo_messaging_rabbit/kombu_ssl_ca_certs').with_value('<SERVICE DEFAULT>')
       is_expected.to contain_neutron_config('oslo_messaging_rabbit/kombu_ssl_certfile').with_value('<SERVICE DEFAULT>')
       is_expected.to contain_neutron_config('oslo_messaging_rabbit/kombu_ssl_keyfile').with_value('<SERVICE DEFAULT>')
-      is_expected.to contain_neutron_config('oslo_messaging_rabbit/kombu_ssl_version').with_ensure('absent')
+      is_expected.to contain_neutron_config('oslo_messaging_rabbit/kombu_ssl_version').with_value('<SERVICE DEFAULT>')
     end
   end
 
-  shared_examples_for 'with SSL wrongly configured' do
-    before do
-      params.merge!(
-        :rabbit_use_ssl => false
-      )
-    end
-
-    context 'with SSL disabled' do
-
-      context 'with kombu_ssl_ca_certs parameter' do
-        before { params.merge!(:kombu_ssl_ca_certs => '/path/to/ssl/ca/certs') }
-        it_raises 'a Puppet::Error', /The kombu_ssl_ca_certs parameter requires rabbit_use_ssl to be set to true/
-      end
-
-      context 'with kombu_ssl_certfile parameter' do
-        before { params.merge!(:kombu_ssl_certfile => '/path/to/ssl/cert/file') }
-        it_raises 'a Puppet::Error', /The kombu_ssl_certfile parameter requires rabbit_use_ssl to be set to true/
-      end
-
-      context 'with kombu_ssl_keyfile parameter' do
-        before { params.merge!(:kombu_ssl_keyfile => '/path/to/ssl/keyfile') }
-        it_raises 'a Puppet::Error', /The kombu_ssl_keyfile parameter requires rabbit_use_ssl to be set to true/
-      end
-    end
-
-  end
-
   shared_examples_for 'with SSL and kombu wrongly configured' do
     before do
       params.merge!(
@@ -354,21 +378,6 @@ describe 'neutron' do
 
     it do
       is_expected.to contain_neutron_config('DEFAULT/use_syslog').with_value(true)
-      is_expected.to contain_neutron_config('DEFAULT/syslog_log_facility').with_value('<SERVICE DEFAULT>')
-    end
-  end
-
-  shared_examples_for 'with syslog enabled and custom settings' do
-    before do
-      params.merge!(
-        :use_syslog    => 'true',
-        :log_facility  => 'LOG_LOCAL0'
-      )
-    end
-
-    it do
-      is_expected.to contain_neutron_config('DEFAULT/use_syslog').with_value(true)
-      is_expected.to contain_neutron_config('DEFAULT/syslog_log_facility').with_value('LOG_LOCAL0')
     end
   end
 
@@ -385,17 +394,6 @@ describe 'neutron' do
     end
   end
 
-  shared_examples_for 'with logging disabled' do
-    before { params.merge!(
-      :log_file => false,
-      :log_dir  => false
-    )}
-    it {
-      is_expected.to contain_neutron_config('DEFAULT/log_file').with_ensure('absent')
-      is_expected.to contain_neutron_config('DEFAULT/log_dir').with_ensure('absent')
-    }
-  end
-
   shared_examples_for 'with state and lock paths set' do
     before { params.merge!(
       :state_path => 'state_path',
@@ -441,27 +439,27 @@ describe 'neutron' do
 
   end
 
-  shared_examples_for 'with network_device_mtu defined' do
+  shared_examples_for 'with global_physnet_mtu defined' do
     before do
       params.merge!(
-        :network_device_mtu => 9000
+        :global_physnet_mtu => 9000
       )
     end
 
     it do
-      is_expected.to contain_neutron_config('DEFAULT/network_device_mtu').with_value(params[:network_device_mtu])
+      is_expected.to contain_neutron_config('DEFAULT/global_physnet_mtu').with_value(params[:global_physnet_mtu])
     end
   end
 
-  shared_examples_for 'with advertise_mtu defined' do
+  shared_examples_for 'with host defined' do
     before do
       params.merge!(
-        :advertise_mtu => true
+        :host => 'test-001.example.org'
       )
     end
 
     it do
-      is_expected.to contain_neutron_config('DEFAULT/advertise_mtu').with_value(params[:advertise_mtu])
+      is_expected.to contain_neutron_config('DEFAULT/host').with_value(params[:host])
     end
   end
 
@@ -477,6 +475,84 @@ describe 'neutron' do
     end
   end
 
+  shared_examples_for 'with transport_url defined' do
+    before do
+      params.merge!(
+        :default_transport_url => 'rabbit://rabbit_user:password@localhost:5673'
+      )
+    end
+
+    it do
+      is_expected.to contain_neutron_config('DEFAULT/transport_url').with_value(params[:default_transport_url])
+    end
+  end
+
+  shared_examples_for 'with rootwrap daemon' do
+    before do
+      params.merge!(
+        :root_helper_daemon => 'sudo neutron-rootwrap-daemon /etc/neutron/rootwrap.conf'
+      )
+    end
+
+    it do
+      is_expected.to contain_neutron_config('agent/root_helper_daemon').with_value(params[:root_helper_daemon])
+    end
+  end
+
+  shared_examples_for 'amqp support' do
+    context 'with default parameters' do
+      before { params.merge!( :rpc_backend => 'amqp' ) }
+
+      it { is_expected.to contain_neutron_config('DEFAULT/rpc_backend').with_value('amqp') }
+      it { is_expected.to contain_neutron_config('oslo_messaging_amqp/server_request_prefix').with_value('<SERVICE DEFAULT>') }
+      it { is_expected.to contain_neutron_config('oslo_messaging_amqp/broadcast_prefix').with_value('<SERVICE DEFAULT>') }
+      it { is_expected.to contain_neutron_config('oslo_messaging_amqp/group_request_prefix').with_value('<SERVICE DEFAULT>') }
+      it { is_expected.to contain_neutron_config('oslo_messaging_amqp/container_name').with_value('<SERVICE DEFAULT>') }
+      it { is_expected.to contain_neutron_config('oslo_messaging_amqp/idle_timeout').with_value('<SERVICE DEFAULT>') }
+      it { is_expected.to contain_neutron_config('oslo_messaging_amqp/trace').with_value('<SERVICE DEFAULT>') }
+      it { is_expected.to contain_neutron_config('oslo_messaging_amqp/ssl_ca_file').with_value('<SERVICE DEFAULT>') }
+      it { is_expected.to contain_neutron_config('oslo_messaging_amqp/ssl_cert_file').with_value('<SERVICE DEFAULT>') }
+      it { is_expected.to contain_neutron_config('oslo_messaging_amqp/ssl_key_file').with_value('<SERVICE DEFAULT>') }
+      it { is_expected.to contain_neutron_config('oslo_messaging_amqp/ssl_key_password').with_value('<SERVICE DEFAULT>') }
+      it { is_expected.to contain_neutron_config('oslo_messaging_amqp/allow_insecure_clients').with_value('<SERVICE DEFAULT>') }
+      it { is_expected.to contain_neutron_config('oslo_messaging_amqp/sasl_mechanisms').with_value('<SERVICE DEFAULT>') }
+      it { is_expected.to contain_neutron_config('oslo_messaging_amqp/sasl_config_dir').with_value('<SERVICE DEFAULT>') }
+      it { is_expected.to contain_neutron_config('oslo_messaging_amqp/sasl_config_name').with_value('<SERVICE DEFAULT>') }
+      it { is_expected.to contain_neutron_config('oslo_messaging_amqp/username').with_value('<SERVICE DEFAULT>') }
+      it { is_expected.to contain_neutron_config('oslo_messaging_amqp/password').with_value('<SERVICE DEFAULT>') }
+    end
+
+    context 'with overriden amqp parameters' do
+      before { params.merge!(
+        :rpc_backend        => 'amqp',
+        :amqp_idle_timeout  => '60',
+        :amqp_trace         => true,
+        :amqp_ssl_ca_file   => '/path/to/ca.cert',
+        :amqp_ssl_cert_file => '/path/to/certfile',
+        :amqp_ssl_key_file  => '/path/to/key',
+        :amqp_username      => 'amqp_user',
+        :amqp_password      => 'password',
+      ) }
+
+      it { is_expected.to contain_neutron_config('DEFAULT/rpc_backend').with_value('amqp') }
+      it { is_expected.to contain_neutron_config('oslo_messaging_amqp/server_request_prefix').with_value('<SERVICE DEFAULT>') }
+      it { is_expected.to contain_neutron_config('oslo_messaging_amqp/broadcast_prefix').with_value('<SERVICE DEFAULT>') }
+      it { is_expected.to contain_neutron_config('oslo_messaging_amqp/group_request_prefix').with_value('<SERVICE DEFAULT>') }
+      it { is_expected.to contain_neutron_config('oslo_messaging_amqp/container_name').with_value('<SERVICE DEFAULT>') }
+      it { is_expected.to contain_neutron_config('oslo_messaging_amqp/idle_timeout').with_value('60') }
+      it { is_expected.to contain_neutron_config('oslo_messaging_amqp/trace').with_value('true') }
+      it { is_expected.to contain_neutron_config('oslo_messaging_amqp/ssl_ca_file').with_value('/path/to/ca.cert') }
+      it { is_expected.to contain_neutron_config('oslo_messaging_amqp/ssl_cert_file').with_value('/path/to/certfile') }
+      it { is_expected.to contain_neutron_config('oslo_messaging_amqp/ssl_key_file').with_value('/path/to/key') }
+      it { is_expected.to contain_neutron_config('oslo_messaging_amqp/allow_insecure_clients').with_value('<SERVICE DEFAULT>') }
+      it { is_expected.to contain_neutron_config('oslo_messaging_amqp/sasl_mechanisms').with_value('<SERVICE DEFAULT>') }
+      it { is_expected.to contain_neutron_config('oslo_messaging_amqp/sasl_config_dir').with_value('<SERVICE DEFAULT>') }
+      it { is_expected.to contain_neutron_config('oslo_messaging_amqp/sasl_config_name').with_value('<SERVICE DEFAULT>') }
+      it { is_expected.to contain_neutron_config('oslo_messaging_amqp/username').with_value('amqp_user') }
+      it { is_expected.to contain_neutron_config('oslo_messaging_amqp/password').with_value('password') }
+    end
+  end
+
   context 'on Debian platforms' do
     let :facts do
       @default_facts.merge(test_facts.merge({
