@@ -42,7 +42,7 @@ describe 'neutron::keystone::auth' do
 
   describe 'when configuring neutron-server' do
     let :pre_condition do
-      "class { 'neutron::server': auth_password => 'test' }"
+      "class { 'neutron::server': password => 'test' }"
     end
 
     let :facts do
@@ -79,29 +79,6 @@ describe 'neutron::keystone::auth' do
     ) }
   end
 
-  describe 'with deprecated endpoint parameters' do
-    let :params do
-      {
-        :password          => 'neutron_password',
-        :public_protocol   => 'https',
-        :public_port       => '80',
-        :public_address    => '10.10.10.10',
-        :port              => '81',
-        :internal_protocol => 'https',
-        :internal_address  => '10.10.10.11',
-        :admin_protocol    => 'https',
-        :admin_address     => '10.10.10.12'
-      }
-    end
-
-    it { is_expected.to contain_keystone_endpoint('RegionOne/neutron::network').with(
-      :ensure       => 'present',
-      :public_url   => "https://10.10.10.10:80",
-      :internal_url => "https://10.10.10.11:81",
-      :admin_url    => "https://10.10.10.12:81"
-    ) }
-  end
-
   describe 'when overriding auth name' do
 
     let :params do
@@ -115,9 +92,9 @@ describe 'neutron::keystone::auth' do
 
     it { is_expected.to contain_keystone_user_role('neutrony@services') }
 
-    it { is_expected.to contain_keystone_service('neutrony::network') }
+    it { is_expected.to contain_keystone_service('neutron::network') }
 
-    it { is_expected.to contain_keystone_endpoint('RegionOne/neutrony::network') }
+    it { is_expected.to contain_keystone_endpoint('RegionOne/neutron::network') }
 
   end
 
