@@ -3,7 +3,7 @@ require 'spec_helper'
 describe 'neutron::plugins::ml2::bigswitch' do
 
   let :pre_condition do
-    "class { 'neutron::server': auth_password => 'password'}
+    "class { 'neutron::server': password => 'password'}
      class { 'neutron':
       rabbit_password => 'passw0rd',
       core_plugin     => 'neutron.plugins.ml2.plugin.Ml2Plugin' }"
