@@ -3,7 +3,7 @@ require 'spec_helper'
 describe 'neutron::plugins::ml2::cisco' do
 
   let :pre_condition do
-    "class { 'neutron::server': auth_password => 'password'}
+    "class { 'neutron::server': password => 'password'}
      class { 'neutron':
       rabbit_password => 'passw0rd',
       core_plugin     => 'neutron.plugins.ml2.plugin.Ml2Plugin' }"
@@ -19,7 +19,7 @@ describe 'neutron::plugins::ml2::cisco' do
     {}
   end
 
-  let :default_facts do
+  let :test_facts do
     {
       :operatingsystem        => 'default',
       :operatingsystemrelease => 'default',
@@ -46,10 +46,10 @@ describe 'neutron::plugins::ml2::cisco' do
   begin
     context 'on RedHat platforms' do
       let :facts do
-        default_facts.merge({
-          :osfamily               => 'RedHat',
-          :operatingsystemrelease => '7'
-        })
+        @default_facts.merge(test_facts.merge({
+           :osfamily               => 'RedHat',
+           :operatingsystemrelease => '7'
+        }))
       end
 
       it_configures 'neutron plugin cisco ml2'
