@@ -39,7 +39,8 @@ describe 'neutron::plugins::ml2' do
       :vni_ranges            => '10:100',
       :path_mtu              => '0',
       :physical_network_mtus => '',
-      :package_ensure        => 'present' }
+      :package_ensure        => 'present',
+      :purge_config          => false, }
   end
 
   let :test_facts do
@@ -63,6 +64,12 @@ describe 'neutron::plugins::ml2' do
         is_expected.to contain_neutron_config('DEFAULT/core_plugin').with_value('neutron.plugins.ml2.plugin.Ml2Plugin')
     end
 
+    it 'passes purge to resource' do
+      is_expected.to contain_resources('neutron_plugin_ml2').with({
+        :purge => false
+      })
+    end
+
     it 'configures ml2_conf.ini' do
       is_expected.to contain_neutron_plugin_ml2('ml2/type_drivers').with_value(p[:type_drivers].join(','))
       is_expected.to contain_neutron_plugin_ml2('ml2/tenant_network_types').with_value(p[:tenant_network_types].join(','))
@@ -70,6 +77,9 @@ describe 'neutron::plugins::ml2' do
       is_expected.to contain_neutron_plugin_ml2('ml2/extension_drivers').with_value('<SERVICE DEFAULT>')
       is_expected.to contain_neutron_plugin_ml2('ml2/path_mtu').with_value(p[:path_mtu])
       is_expected.to contain_neutron_plugin_ml2('ml2/physical_network_mtus').with_ensure('absent')
+      is_expected.to contain_neutron_plugin_ml2('ml2/overlay_ip_version').with_value('<SERVICE DEFAULT>')
+      is_expected.to contain_neutron_plugin_ml2('securitygroup/firewall_driver').with_value('<SERVICE DEFAULT>')
+      is_expected.to contain_neutron_plugin_ml2('securitygroup/enable_security_group').with_value('<SERVICE DEFAULT>')
     end
 
     it 'creates plugin symbolic link' do
@@ -84,8 +94,51 @@ describe 'neutron::plugins::ml2' do
         is_expected.to contain_package('neutron-plugin-ml2').with(
           :name   => platform_params[:ml2_server_package],
           :ensure => p[:package_ensure],
-          :tag    => 'openstack'
+          :tag    => ['neutron-package', 'openstack'],
         )
+        is_expected.to contain_package('neutron-plugin-ml2').that_requires('Anchor[neutron::install::begin]')
+        is_expected.to contain_package('neutron-plugin-ml2').that_notifies('Anchor[neutron::install::end]')
+      end
+    end
+
+
+    context 'when overriding security group options' do
+      before :each do
+        params.merge!(
+          :enable_security_group => true,
+          :firewall_driver       => 'neutron.agent.linux.iptables_firewall.OVSHybridIptablesFirewallDriver',
+        )
+      end
+      it 'configures enable_security_group and firewall_driver options' do
+        is_expected.to contain_neutron_plugin_ml2('securitygroup/enable_security_group').with_value('true')
+        is_expected.to contain_neutron_plugin_ml2('securitygroup/firewall_driver').with_value('neutron.agent.linux.iptables_firewall.OVSHybridIptablesFirewallDriver')
+      end
+    end
+
+    context 'when specifying IPv4 overlays' do
+      before :each do
+        params.merge!(:overlay_ip_version => 4)
+      end
+      it 'configures as IPv4' do
+        is_expected.to contain_neutron_plugin_ml2('ml2/overlay_ip_version').with_value(4)
+      end
+    end
+
+    context 'when specifying IPv6 overlays' do
+      before :each do
+        params.merge!(:overlay_ip_version => 6)
+      end
+      it 'configures as IPv6' do
+        is_expected.to contain_neutron_plugin_ml2('ml2/overlay_ip_version').with_value(6)
+      end
+    end
+
+    context 'when specifying an invalid overlay IP versions' do
+      before :each do
+        params.merge!(:overlay_ip_version => 10)
+      end
+      it 'fails to accept value' do
+        is_expected.to raise_error(Puppet::Error)
       end
     end
 
@@ -184,6 +237,21 @@ describe 'neutron::plugins::ml2' do
       it_raises  'a Puppet::Error', /vni ranges are invalid./
     end
 
+    context 'when using geneve driver' do
+      before :each do
+        params.merge!(:type_drivers    => ['local', 'flat', 'vlan', 'gre', 'vxlan', 'geneve'],
+                      :vni_ranges      => ['40:300','500:1000'],
+                      :max_header_size => 50
+        )
+      end
+
+      it 'configures geneve with valid values' do
+        is_expected.to contain_neutron_plugin_ml2('ml2/type_drivers').with_value(p[:type_drivers].join(','))
+        is_expected.to contain_neutron_plugin_ml2('ml2_type_geneve/vni_ranges').with_value([p[:vni_ranges].join(',')])
+        is_expected.to contain_neutron_plugin_ml2('ml2_type_geneve/max_header_size').with_value(p[:max_header_size])
+      end
+    end
+
     context 'with path_mtu set' do
       before :each do
         params.merge!(:path_mtu => '9000')
@@ -213,7 +281,7 @@ describe 'neutron::plugins::ml2' do
           is_expected.to contain_package('neutron-plugin-ml2').with(
             :name   => platform_params[:ml2_server_package],
             :ensure => params[:package_ensure],
-            :tag    => 'openstack'
+            :tag    => ['neutron-package', 'openstack'],
           )
         end
       end
@@ -223,11 +291,9 @@ describe 'neutron::plugins::ml2' do
       before :each do
         params.merge!(
           :mechanism_drivers    => ['openvswitch', 'sriovnicswitch'],
-          :sriov_agent_required => true,
         )
       end
-      it 'configures sriov mechanism driver with agent_enabled' do
-        is_expected.to contain_neutron_plugin_sriov('ml2_sriov/agent_required').with_value('true')
+      it 'configures sriov mechanism driver' do
         is_expected.to contain_neutron_plugin_sriov('ml2_sriov/supported_pci_vendor_devs').with_value(['15b3:1004,8086:10ca'])
       end
     end
@@ -242,8 +308,9 @@ describe 'neutron::plugins::ml2' do
           :path    => '/etc/default/neutron-server',
           :match   => '^NEUTRON_PLUGIN_CONFIG=(.*)$',
           :line    => 'NEUTRON_PLUGIN_CONFIG=/etc/neutron/plugin.ini',
-          :require => ['File[/etc/default/neutron-server]','File[/etc/neutron/plugin.ini]']
         )
+        is_expected.to contain_file_line('/etc/default/neutron-server:NEUTRON_PLUGIN_CONFIG').that_requires('Anchor[neutron::config::begin]')
+        is_expected.to contain_file_line('/etc/default/neutron-server:NEUTRON_PLUGIN_CONFIG').that_notifies('Anchor[neutron::config::end]')
       end
     end
   end
