@@ -3,7 +3,7 @@ require 'spec_helper'
 describe 'neutron::plugins::opencontrail' do
 
   let :pre_condition do
-    "class { 'neutron::server': auth_password => 'password' }
+    "class { 'neutron::server': password => 'password' }
      class { 'neutron': rabbit_password => 'passw0rd' }"
   end
 
@@ -16,7 +16,8 @@ describe 'neutron::plugins::opencontrail' do
       :keystone_admin_user        => 'admin',
       :keystone_admin_tenant_name => 'admin',
       :keystone_admin_password    => 'admin',
-      :keystone_admin_token       => 'token1'
+      :keystone_admin_token       => 'token1',
+      :purge_config               => false,
     }
   end
 
@@ -36,6 +37,12 @@ describe 'neutron::plugins::opencontrail' do
       params.merge!(default_params)
     end
 
+    it 'passes purge to resource' do
+      is_expected.to contain_resources('neutron_plugin_opencontrail').with({
+        :purge => false
+      })
+    end
+
     it 'should perform default configuration of' do
       is_expected.to contain_neutron_plugin_opencontrail('APISERVER/api_server_ip').with_value(params[:api_server_ip])
       is_expected.to contain_neutron_plugin_opencontrail('APISERVER/api_server_port').with_value(params[:api_server_port])
@@ -66,9 +73,10 @@ describe 'neutron::plugins::opencontrail' do
         :path    => '/etc/default/neutron-server',
         :match   => '^NEUTRON_PLUGIN_CONFIG=(.*)$',
         :line    => 'NEUTRON_PLUGIN_CONFIG=/etc/neutron/plugins/opencontrail/ContrailPlugin.ini',
-        :require => ['Package[neutron-server]', 'Package[neutron-plugin-contrail]'],
-        :notify  => 'Service[neutron-server]'
+        :tag     => 'neutron-file-line',
       )
+      is_expected.to contain_file_line('/etc/default/neutron-server:NEUTRON_PLUGIN_CONFIG').that_requires('Anchor[neutron::config::begin]')
+      is_expected.to contain_file_line('/etc/default/neutron-server:NEUTRON_PLUGIN_CONFIG').that_notifies('Anchor[neutron::config::end]')
     end
     it_configures 'neutron opencontrail plugin'
   end
